aboutsummaryrefslogtreecommitdiffstats
path: root/wsutil
diff options
context:
space:
mode:
Diffstat (limited to 'wsutil')
-rw-r--r--wsutil/time_util.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/wsutil/time_util.h b/wsutil/time_util.h
index 16e0a8626f..2835d68ef3 100644
--- a/wsutil/time_util.h
+++ b/wsutil/time_util.h
@@ -38,11 +38,11 @@ time_t mktime_utc(struct tm *tm);
* Fetch the current process user and system CPU times, convert them to
* seconds, and store them in the provided parameters.
*
* @param utime Seconds spent in user mode.
* @param stime Seconds spent in system (kernel) mode.
*/
WS_DLL_PUBLIC
-void get_resource_usage(double *utime, double *stime);
+void get_resource_usage(double *user_time, double *sys_time);
/** Print the process CPU time followed by a log message.
*
@@ -38,11 +38,11 @@ time_t mktime_utc(struct tm *tm);
* seconds, and store them in the provided parameters.
*
- * @param utime Seconds spent in user mode.
- * @param stime Seconds spent in system (kernel) mode.
+ * @param user_time Seconds spent in user mode.
+ * @param sys_time Seconds spent in system (kernel) mode.
*/
WS_DLL_PUBLIC